#!/bin/sh
#--------------------------------------------------------------------
# mkrootfs.sh
#--------------------------------------------------------------------

# mkroofs.sh should be excuted at ramdisk-boot mode

IS_INITRD_BOOT=`cat /proc/cmdline | grep -c "initrd="`
if [ $IS_INITRD_BOOT -ne 1 ]; then
	echo "mkrootfs.sh should be excuted at ramdisk-boot mode"
	exit 0
fi

FWUPDATEPOST_FLAG=/fwupdate_done
FWUPDATE_LOG=/fwupdate.log

if [ -f $FWUPDATEPOST_FLAG ]; then
	echo "Already excuted $0"
	exit 0
fi

PATH=/sbin:/usr/sbin:/bin:/usr/bin:$PATH
export PATH

#check 1st argument, if exist, run argv1
if [ $# -eq 1 ]; then
	[ -x $1 ] && $1
fi

SYFT_SIZE=0

function get_syft_length()
{
	SYFT_ID=$1
#	echo syft id $SYFT_ID
	SIZE=`/usr/sbin/fuc -d | /bin/grep ^${SYFT_ID} | /usr/bin/awk '{print $3}' | /bin/sed 's/0x//g'`
	SYFT_SIZE=$((16#${SIZE}))	
#	echo syft size $SIZE
}

function write_log_msg()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	echo "$1" >> $FWUPDATE_LOG
}

function cmd_out_log()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	$1 >> $FWUPDATE_LOG
}

echo
echo "Start making the new rootfs ..."

write_log_msg "Start mkrootfs.sh"

if [ -f /etc/fwfwid ]; then
	. /etc/fwfwid
else
	FWFWID=ga
fi


CI_MTD=/dev/mtd6
CI_IMG=/ci.tar.gz


cmd_out_log /bin/mount
cmd_out_log "/bin/df -h"

cd /mnt/rfs

# make root fs
# untar repository files

# XYZ : 1xx ~ 3xx
REPO_DIR=/mnt/repo
RF_LIST=`ls $REPO_DIR/rf_${FWFWID}-[rsw]i*.tar.gz`

# extract rf's
for RF in $RF_LIST
do
	echo
	echo "Extract $RF"

	tar xzf ${RF}

	/bin/sync
done


# Make default config
DEF_CFG=etc/default_conf.tgz
echo -n "Make default config  "
. etc/sysconfig/_conf.list
/bin/tar czf $DEF_CFG $FILES_TO_COMPRESS
echo "[ Done ]"
write_log_msg "Make default config"

# Config Image
get_syft_length 02
CI_SIZE=$SYFT_SIZE
echo ci size $CI_SIZE
if [ $CI_SIZE -gt 0 ]; then
	write_log_msg "Extract CI size=$CI_SIZE"
	/usr/sbin/nanddump -o -B -l $CI_SIZE -f $CI_IMG $CI_MTD
	/bin/tar xzf $CI_IMG
	rm $CI_IMG
	sync
	cmd_out_log "/bin/df -h"
fi

# FES
RF_LIST=`ls $REPO_DIR/rf_${FWFWID}-fe*.tar.gz`

# extract rf's
for RF in $RF_LIST
do
	echo
	echo "Extract $RF"

	tar xzf ${RF}

	/bin/sync
done

# run additional script in rf's
EXTRA_SCRIPT=/mnt/rfs/opt/nss/bin/mkrootfspost.sh
if [ -x "$EXTRA_SCRIPT" ]; then
	echo
	echo    "Run the additional script."
	echo

	$EXTRA_SCRIPT
fi


# make bootmode as normal boot
/usr/sbin/fuc -sh sft-config offset=19 data=0

/bin/touch $FWUPDATEPOST_FLAG


write_log_msg "End of fwupdatepost.sh"

exit 0
